==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_router/neustar/src/test/java/configuration/ServiceRefresherTest.java <==
/*
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package configuration;

import com.comcast.cdn.traffic_control.traffic_router.neustar.NeustarGeolocationService;
import com.comcast.cdn.traffic_control.traffic_router.neustar.configuration.ServiceRefresher;
import com.comcast.cdn.traffic_control.traffic_router.neustar.data.NeustarDatabaseUpdater;
import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;
import static org.mockito.MockitoAnnotations.initMocks;

public class ServiceRefresherTest {
	@Mock
	NeustarDatabaseUpdater neustarDatabaseUpdater;

	@Mock
	NeustarGeolocationService neustarGeolocationService;

	@InjectMocks
	ServiceRefresher serviceRefresher;

	@Before
	public void before() {
		initMocks(this);
	}

	@Test
	public void itSwallowsExceptions() {
		when(neustarDatabaseUpdater.update()).thenThrow(new RuntimeException("Boom!"));
		serviceRefresher.run();
		verify(neustarDatabaseUpdater).update();
	}
}

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_router/neustar/src/test/java/configuration/ServiceRefresherTest.java <==
/*
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package configuration;

import org.apache.traffic_control.traffic_router.neustar.NeustarGeolocationService;
import org.apache.traffic_control.traffic_router.neustar.configuration.ServiceRefresher;
import org.apache.traffic_control.traffic_router.neustar.data.NeustarDatabaseUpdater;
import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;
import static org.mockito.MockitoAnnotations.initMocks;

public class ServiceRefresherTest {
	@Mock
	NeustarDatabaseUpdater neustarDatabaseUpdater;

	@Mock
	NeustarGeolocationService neustarGeolocationService;

	@InjectMocks
	ServiceRefresher serviceRefresher;

	@Before
	public void before() {
		initMocks(this);
	}

	@Test
	public void itSwallowsExceptions() {
		when(neustarDatabaseUpdater.update()).thenThrow(new RuntimeException("Boom!"));
		serviceRefresher.run();
		verify(neustarDatabaseUpdater).update();
	}
}
